import Fade from '@material-ui/core/Fade';
import { fade, lighten, darken } from '@material-ui/core/styles/colorManipulator';
import makeStyles$1 from '@material-ui/core/styles/makeStyles';
import CloseIcon from '@material-ui/icons/Close';
import clsx from 'clsx';
import React__default, { useContext, forwardRef, createElement, Fragment } from 'react';
import { makeStyles, useTheme, styled, fade as fade$2 } from '@material-ui/core/styles';
import MUITypography from '@material-ui/core/Typography';
import MUIButton from '@material-ui/core/Button';
import MUICard from '@material-ui/core/Card';
export { default as CardActionArea } from '@material-ui/core/CardActionArea';
export { default as CardActions } from '@material-ui/core/CardActions';
export { default as CardContent } from '@material-ui/core/CardContent';
export { default as CardMedia } from '@material-ui/core/CardMedia';
import { makeStyles as makeStyles$2, fade as fade$1, Tooltip as Tooltip$1, lighten as lighten$1 } from '@material-ui/core';
import Paper from '@material-ui/core/Paper';
import MuiTab from '@material-ui/core/Tab';
import MuiTabs from '@material-ui/core/Tabs';

var bootstrapColors = ["primary", "secondary", "success", "danger", "warning", "info", "light", "dark"];
var bootstrapPalette = function bootstrapPalette(theme) {
  return {
    primary: {
      contrastText: theme.palette.primary.contrastText,
      main: theme.palette.primary.main
    },
    secondary: {
      contrastText: theme.palette.secondary.contrastText,
      main: theme.palette.secondary.main
    },
    success: {
      contrastText: "#fff",
      main: "#5cb85c"
    },
    danger: {
      contrastText: "#fff",
      main: "#d9534f"
    },
    warning: {
      contrastText: "#333",
      main: "#f0ad4e"
    },
    info: {
      contrastText: "#fff",
      main: "#5bc0de"
    },
    light: {
      contrastText: theme.palette.text.secondary,
      main: theme.palette.background.paper
    },
    dark: {
      contrastText: theme.palette.background.paper,
      main: theme.palette.text.primary
    }
  };
};

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var useStyles = /*#__PURE__*/makeStyles(function (theme) {
  var bootstrapColors = {
    primary: {
      color: theme.palette.primary.main
    },
    secondary: {
      color: theme.palette.secondary.main
    },
    success: {
      color: "#218838"
    },
    danger: {
      color: "#c82333"
    },
    warning: {
      color: "#e0a800"
    },
    info: {
      color: "#138496"
    },
    light: {
      color: theme.palette.text.secondary
    },
    dark: {
      color: theme.palette.text.primary
    }
  };

  function getColor(x) {
    return x.color === "inherit" ? {
      color: undefined
    } : bootstrapColors[x.color === undefined ? "dark" : x.color];
  }

  return {
    root: {
      color: function color(x) {
        return getColor(x).color;
      },
      "& a": {
        color: function color(x) {
          return getColor(x).color;
        },
        fontWeight: "bolder",
        textDecoration: "none",
        "&:hover": {
          textDecoration: "underline"
        }
      }
    }
  };
});
var Typography = /*#__PURE__*/React__default.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React__default.createElement(MUITypography, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref
  }));
});

function bootstrapAlertStyles(color, theme) {
  var palette = bootstrapPalette(theme);
  var clr = color === "light" ? theme.palette.text.secondary : color === "dark" ? theme.palette.text.primary : palette[color].main;
  var borderColor = color === "light" || color === "dark" ? theme.palette.divider : fade(lighten(clr, 0.6), 0.8);
  var backgroundColor = color === "light" ? fade(theme.palette.text.secondary, 0.035) : color === "dark" ? fade(theme.palette.text.primary, 0.95) : fade(lighten(clr, 0.8), 0.95);
  var headerColor = color === "light" ? fade(theme.palette.text.primary, 0.9) : color === "dark" ? fade(theme.palette.background.paper, 0.9) : darken(clr, 0.6);
  return {
    borderColor: borderColor,
    backgroundColor: backgroundColor,
    headerColor: headerColor
  };
}

var useStyles$1 = function useStyles(color) {
  return makeStyles$1(function (theme) {
    var _maxWidthXs, _maxWidthSm, _maxWidthMd, _maxWidthLg, _maxWidthXl;

    // @ts-ignore
    var htmlFontSize = theme.typography.htmlFontSize;
    var coef = theme.typography.fontSize / 14;

    var pxToRem = function pxToRem(size) {
      return size / htmlFontSize * coef + "rem";
    };

    var _bootstrapAlertStyles = bootstrapAlertStyles(color, theme),
        borderColor = _bootstrapAlertStyles.borderColor,
        backgroundColor = _bootstrapAlertStyles.backgroundColor,
        headerColor = _bootstrapAlertStyles.headerColor;

    return {
      root: {
        color: headerColor,
        backgroundColor: backgroundColor,
        borderColor: borderColor,
        position: "relative",
        border: "1px solid",
        padding: pxToRem(12) + " " + pxToRem(14),
        paddingRight: "" + pxToRem(28),
        borderRadius: pxToRem(4),
        "& a": {
          color: headerColor
        },
        "& p": {
          margin: 0
        }
      },
      closeIcon: {
        fontSize: pxToRem(18),
        right: 12,
        position: "absolute",
        cursor: "pointer",
        "&:hover": {
          color: "#333"
        }
      },

      /* Styles applied to the root element if `maxWidth="xs"`. */
      maxWidthXs: (_maxWidthXs = {}, _maxWidthXs[theme.breakpoints.up("xs")] = {
        maxWidth: Math.max(theme.breakpoints.values.xs, 444)
      }, _maxWidthXs),

      /* Styles applied to the root element if `maxWidth="sm"`. */
      maxWidthSm: (_maxWidthSm = {}, _maxWidthSm[theme.breakpoints.up("sm")] = {
        maxWidth: theme.breakpoints.values.sm
      }, _maxWidthSm),

      /* Styles applied to the root element if `maxWidth="md"`. */
      maxWidthMd: (_maxWidthMd = {}, _maxWidthMd[theme.breakpoints.up("md")] = {
        maxWidth: theme.breakpoints.values.md
      }, _maxWidthMd),

      /* Styles applied to the root element if `maxWidth="lg"`. */
      maxWidthLg: (_maxWidthLg = {}, _maxWidthLg[theme.breakpoints.up("lg")] = {
        maxWidth: theme.breakpoints.values.lg
      }, _maxWidthLg),

      /* Styles applied to the root element if `maxWidth="xl"`. */
      maxWidthXl: (_maxWidthXl = {}, _maxWidthXl[theme.breakpoints.up("xl")] = {
        maxWidth: theme.breakpoints.values.xl
      }, _maxWidthXl)
    };
  });
};

function Alert(props) {
  var classes = useStyles$1(props.color || "danger")(props);

  var _React$useState = React__default.useState(true),
      show = _React$useState[0],
      setShow = _React$useState[1];

  React__default.useEffect(function () {
    if (props.show !== undefined) {
      setShow(props.show);
    }
  }, [props.show]);

  function handleDismiss() {
    setShow(false);

    if (props.onClose !== undefined) {
      props.onClose();
    }
  }

  var maxWidthClass = classes.maxWidthMd;

  switch (props.maxWidth) {
    case "xl":
      maxWidthClass = classes.maxWidthXl;
      break;

    case "lg":
      maxWidthClass = classes.maxWidthLg;
      break;

    case "md":
      maxWidthClass = classes.maxWidthMd;
      break;

    case "sm":
      maxWidthClass = classes.maxWidthSm;
      break;

    case "xs":
      maxWidthClass = classes.maxWidthXs;
      break;
  }

  return React__default.createElement(Fade, {
    "in": show,
    unmountOnExit: true
  }, React__default.createElement("div", {
    className: clsx(classes.root, maxWidthClass)
  }, props.dismissible && React__default.createElement(CloseIcon, {
    onClick: handleDismiss,
    className: classes.closeIcon,
    color: "inherit"
  }), React__default.createElement(Typography, {
    color: "inherit"
  }, props.children)));
}
var useStylesForHeading = /*#__PURE__*/makeStyles$1({
  icon: {
    marginRight: 10,
    verticalAlign: -6,
    "& > *:first-child": {
      fontSize: 32
    }
  }
});

function Heading(props) {
  var classes = useStylesForHeading();
  return React__default.createElement(Typography, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.icon && React__default.createElement("span", {
    className: classes.icon
  }, props.icon), props.children);
}

Alert.Heading = Heading;

var useStyles$2 = /*#__PURE__*/makeStyles(function (theme) {
  var bootstrapColors = _extends({}, bootstrapPalette(theme));

  function getColor(x) {
    return bootstrapColors[x.color === undefined ? "dark" : x.color];
  }

  return {
    root: {
      textTransform: function textTransform(props) {
        return props.uppercase === true ? undefined : "none";
      },
      boxShadow: function boxShadow(props) {
        return props.boxShadow === true ? undefined : "none";
      },
      "&.Mui-disabled": {
        opacity: 0.3
      },
      "&.MuiButton-contained": {
        color: function color(x) {
          return getColor(x).contrastText;
        },
        backgroundColor: function backgroundColor(x) {
          return getColor(x).main;
        },
        "&:hover": {
          backgroundColor: function backgroundColor(x) {
            return darken(getColor(x).main, 0.25);
          }
        }
      },
      "&.MuiButton-outlined,&.MuiButton-text": {
        color: function color(x) {
          return x.color === "light" ? getColor(x).contrastText : getColor(x).main;
        },
        borderColor: function borderColor(x) {
          return x.color === "light" ? fade(darken(getColor(x).main, 0.3), 0.3) : getColor(x).main;
        },
        "&:hover": {
          backgroundColor: function backgroundColor(x) {
            return x.color === "light" ? fade(lighten(getColor(x).contrastText, 0.2), 0.15) : fade(lighten(getColor(x).main, 0.2), 0.15);
          },
          borderColor: function borderColor(x) {
            return x.color === "light" ? lighten(getColor(x).contrastText, 0.5) : lighten(getColor(x).main, 0.5);
          },
          color: function color(x) {
            return x.color === "light" ? lighten(getColor(x).contrastText, 0.3) : lighten(getColor(x).main, 0.3);
          }
        }
      },
      "&:hover": {
        boxShadow: "none"
      }
    }
  };
});
var Button = /*#__PURE__*/React__default.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles$2(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React__default.createElement(MUIButton, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref
  }));
});
Button.defaultProps = {
  size: "medium",
  color: "dark"
};
Button.defaultProps = {
  uppercase: false,
  boxShadow: false
};

var useStyles$3 = function useStyles(color) {
  return makeStyles(function (theme) {
    var palette = bootstrapPalette(theme);
    var backgroundColor = lighten(palette[color].main, 0.3);
    var foreColor = palette[color].contrastText;
    return {
      root: {
        backgroundColor: backgroundColor,
        color: foreColor,
        "& a": {
          color: foreColor,
          fontWeight: "bolder",
          textDecoration: "none",
          "&:hover": {
            textDecoration: "underline"
          }
        }
      }
    };
  });
};

var Card = /*#__PURE__*/React__default.forwardRef(function BootstrapButton(props, ref) {
  var classes = useStyles$3(props.color || "light")(props);

  var otherProps = _objectWithoutPropertiesLoose(props, ["color"]);

  return React__default.createElement(MUICard, Object.assign({}, otherProps, {
    classes: classes,
    ref: ref,
    variant: "outlined"
  }));
});
function CardHeader(props) {
  var classes = makeStyles(function (theme) {
    return {
      root: {
        padding: "10px 14px 10px 14px",
        backgroundColor: fade("#000", 0.1),
        borderBottom: "1px solid " + theme.palette.divider
      }
    };
  })();
  return React__default.createElement("div", {
    className: classes.root
  }, React__default.createElement(Typography, {
    color: "inherit"
  }, props.children));
}
function CardTitle(props) {
  return React__default.createElement(Typography, {
    color: "inherit",
    variant: "h5",
    component: "h2"
  }, props.children);
}

var useStyles$4 = function useStyles(color) {
  return makeStyles$2(function (theme) {
    var palette = bootstrapPalette(theme);
    var foreColor = palette[color].contrastText;
    var backgroundColor = color === "light" ? fade$1(theme.palette.text.secondary, 0.1) : color === "dark" ? fade$1(theme.palette.text.primary, 0.85) : palette[color].main;
    return {
      root: {
        display: "inline-block",
        padding: ".2em .4em",
        borderRadius: ".35rem",
        color: foreColor,
        backgroundColor: backgroundColor
      }
    };
  });
};

function Label(props) {
  var classes = useStyles$4(props.color)();
  return React__default.createElement("span", {
    className: clsx(classes.root)
  }, props.children);
}

var PanelContext = /*#__PURE__*/React__default.createContext("primary");

var useStyles$5 = function useStyles(color) {
  return makeStyles$2(function (theme) {
    var _bootstrapAlertStyles = bootstrapAlertStyles(color, theme),
        borderColor = _bootstrapAlertStyles.borderColor,
        backgroundColor = _bootstrapAlertStyles.backgroundColor,
        headerColor = _bootstrapAlertStyles.headerColor;

    return {
      root: {
        overflow: "hidden",
        borderRadius: 4,
        border: "1px solid " + borderColor,
        backgroundColor: theme.palette.background.paper
      },
      header: {
        borderBottom: "1px solid " + borderColor,
        backgroundColor: backgroundColor,
        color: headerColor,
        padding: "10px 15px"
      },
      body: {
        padding: 15
      }
    };
  });
};

function Panel(props) {
  var classes = useStyles$5(props.color)();
  return React__default.createElement("div", {
    className: classes.root
  }, React__default.createElement(PanelContext.Provider, {
    value: props.color
  }, props.children));
}
function PanelHeader(props) {
  var color = useContext(PanelContext);
  var classes = useStyles$5(color)();
  return React__default.createElement("div", {
    className: classes.header
  }, props.children);
}
function PanelBody(props) {
  var color = useContext(PanelContext);
  var classes = useStyles$5(color)();
  return React__default.createElement("div", {
    className: classes.body
  }, props.children);
}

var StyledTabs = /*#__PURE__*/styled(function (props) {
  return createElement(MuiTabs, Object.assign({}, props));
})(function () {
  return {
    marginBottom: -1,
    "& .MuiTabs-scroller": {
      overflow: "visible !important"
    },
    "& .MuiTabs-indicator": {
      display: "none"
    }
  };
});
var StyledTab = /*#__PURE__*/styled(function (props) {
  return createElement(MuiTab, Object.assign({
    disableRipple: true
  }, props));
})(function (_ref) {
  var theme = _ref.theme;
  return {
    textTransform: "none",
    borderLeft: "1px solid " + fade$2(theme.palette.divider, 0),
    borderRight: "1px solid " + fade$2(theme.palette.divider, 0),
    borderTop: "1px solid " + fade$2(theme.palette.divider, 0),
    color: theme.palette.primary.main,
    borderTopLeftRadius: 6,
    borderTopRightRadius: 6,
    minWidth: 64,
    ":hover": {
      borderLeft: "1px solid " + fade$2(theme.palette.primary.main, 0.25),
      borderRight: "1px solid " + fade$2(theme.palette.primary.main, 0.25),
      borderTop: "1px solid " + fade$2(theme.palette.primary.main, 0.25)
    },
    "&.Mui-selected": {
      color: theme.palette.text.secondary,
      backgroundColor: theme.palette.background.paper,
      borderLeft: "1px solid " + theme.palette.divider,
      borderRight: "1px solid " + theme.palette.divider,
      borderTop: "1px solid " + theme.palette.divider
    }
  };
});
var Tabs = /*#__PURE__*/forwardRef(function (_ref2, ref) {
  var tabs = _ref2.tabs,
      children = _ref2.children,
      selectedIndex = _ref2.selectedIndex,
      onSelect = _ref2.onSelect,
      props = _objectWithoutPropertiesLoose(_ref2, ["tabs", "children", "selectedIndex", "onSelect"]);

  var theme = useTheme();
  return createElement(Fragment, null, createElement(StyledTabs, Object.assign({
    ref: ref
  }, props, {
    value: selectedIndex
  }), tabs.map(function (tab) {
    if (typeof tab === "string") {
      return {
        label: tab
      };
    }

    return tab;
  }).map(function (tab, index) {
    return createElement(StyledTab, Object.assign({
      key: index
    }, tab, {
      value: index,
      onClick: function onClick() {
        return onSelect(index);
      }
    }));
  })), createElement(Paper, {
    variant: "outlined",
    style: {
      padding: theme.spacing(3),
      borderTopLeftRadius: selectedIndex === 0 ? 0 : undefined
    }
  }, children));
});

var useStyles$6 = /*#__PURE__*/makeStyles$2(function (theme) {
  var backgroundColor = lighten$1(theme.palette.common.black, 0.15);
  return {
    arrow: {
      color: backgroundColor
    },
    tooltip: {
      fontWeight: theme.typography.body1.fontWeight,
      fontSize: theme.typography.body1.fontSize,
      backgroundColor: backgroundColor
    }
  };
});
var Tooltip = /*#__PURE__*/React__default.forwardRef(function (props, ref) {
  var classes = useStyles$6();
  return React__default.createElement(Tooltip$1, Object.assign({
    ref: ref
  }, props, {
    arrow: true,
    classes: classes
  }));
});

export { Alert, Button, Card, CardHeader, CardTitle, Label, Panel, PanelBody, PanelHeader, Tabs, Tooltip, Typography, bootstrapColors, bootstrapPalette };
//# sourceMappingURL=material-ui-bootstrap.esm.js.map
